@@ -3,6 +3,7 @@ import json
 import logging
 import os
 import ssl
+import sys
 import time
 import warnings
 import webbrowser
@@ -106,7 +107,7 @@ class Configuration(client.Configuration):
         self,
         *,
         grant_type="authorization_code",
-        client_id="PythonClient",
+        client_id=None,
         client_secret="",
         username="",
         offline=False,
@@ -115,7 +116,7 @@ class Configuration(client.Configuration):
         super(Configuration, self).__init__(host=host)
 
         self.grant_type = grant_type
-        self.client_id = client_id
+        self._client_id = client_id
         self.client_secret = client_secret
         self.username = username
         self.password = ""
@@ -126,6 +127,21 @@ class Configuration(client.Configuration):
         self._proxy = None
         self._auth_backoff = False
 
+    @property
+    def client_id(self):
+        if self._client_id is None:
+            self.client_id = "PythonClient"
+        return self._client_id
+
+    @client_id.setter
+    def client_id(self, value):
+        if value == "PythonClient":
+            print("Warning: 'PythonClient' client_id is being deprecated."
+                  " Please generate a custom client config to continue using the API"
+                  "\nFor more information about generating a client, please visit "
+                  "https://docs.intellegens.com/alchemite-tm-api/getting-started/generating-a-client", file=sys.stderr)
+
+        self._client_id = value
 
     @property
     def token_endpoint(self):
