@@ -16,22 +16,10 @@ api_datasets = client.DatasetsApi(client.ApiClient(configuration))
 ### Provide path to the JSON containing your credentials
 configuration.credentials = "credentials.json"
 
-SUGGEST_DATASET = "steels"  # 'steels' or 'vector'
-
-if SUGGEST_DATASET == "steels":
-    dataset_file = "steels.csv"
-    dataset_name = "steels"
-    model_name = "steels"
-    suggest_args = "suggest_historic_args_steel.json"
-    vector_pairs = None
-elif SUGGEST_DATASET == "vector":
-    dataset_file = "vector.csv"
-    dataset_name = "vector"
-    model_name = "vector"
-    suggest_args = "suggest_historic_args_vector.json"
-    vector_pairs = [["z", "t"]]
-else:
-    raise Exception("Invalid suggest dataset option")
+dataset_file = "steels.csv"
+dataset_name = "steels"
+model_name = "steels"
+suggest_args = "suggest_historic_args_steel.json"
 
 # Check we can access the API by getting the version number from GET /version
 api_response = api_default.version_get()
@@ -57,7 +45,6 @@ dataset = {
     # No descriptors in this dataset so list of zeros
     "descriptor_columns": [0] * len(column_headers),
     "data": data,
-    "vector_pairs": vector_pairs,
 }
 dataset_id = api_datasets.datasets_post(dataset=dataset)
 print("dataset ID:", dataset_id)
